@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-VERSION = '0.3.3'
+VERSION = '0.3.4'
 
 import os
 import sys
@@ -14,16 +14,10 @@ import subprocess
 import multiprocessing
 import argparse
 import string
-import curses
-
-width = 20
-def set_screen_width(screen):
-    global width
-    try:
-        (_, width) = screen.getmaxyx()
-    except:
-        width = 20
+import random
+import time
 
+width = shutil.get_terminal_size((20,0)).columns
 
 def get_args():
     parser = argparse.ArgumentParser(
@@ -234,8 +228,12 @@ class Kernel(object):
         if not os.path.isfile(source):
             raise EnvironmentError('Archived kernel does not exist')
         self.log('Extracting kernel')
+        if self.verbose:
+            callback = extract_progress
+        else:
+            callback = None
         try:
-            archive = TarFileWithProgress.open(source, callback=extract_progress)
+            archive = TarFileWithProgress.open(source, callback=callback)
             archive.extractall(destination)
         except:
             shutil.rmtree(
@@ -313,7 +311,17 @@ class Kernel(object):
         if jobs is None:
             jobs = str(multiprocessing.cpu_count())
         self.log('Making the kernel')
-        subprocess.call(['make', '-j' + jobs], stdout=stdout, stderr=stdout)
+        make_process = subprocess.Popen(
+            ['make', '-j' + jobs],
+            stdout=stdout,
+            stderr=stdout,
+        )
+        while make_process.poll() is None:
+            progress_bar(random.randint(1, 99), 100)
+            time.sleep(1)
+        if make_process.returncode != 0:
+            print('Failed to make kernel')
+            raise SystemExit
 
     @require_attr('version')
     @require_attr('revision')
@@ -370,9 +378,6 @@ def easy_roll():
     args = get_args()
     kernel = Kernel(verbose=args.verbose)
 
-    if args.verbose:
-        curses.wrapper(set_screen_width)
-
     kernel.version = args.new_version
     kernel.config_version = args.config_version
     kernel.config_revision = args.config_revision
